@@ -220,6 +220,7 @@ class DccTool(plugin.Plugin, object):
         tool_kwargs['collapsable'] = False
         tool_kwargs['show_item_icon'] = False
         toolset_inst = toolset_class(**tool_kwargs)
+        toolset_inst.client = toolset_inst.setup_client()
         toolset_inst.pre_content_setup()
         toolset_contents = toolset_inst.contents()
         for toolset_widget in toolset_contents:
@@ -317,6 +318,8 @@ class DccTool(plugin.Plugin, object):
                 tb = traceback.format_exception(exc_type, exc_value, exc_tb)
             self._stats.finish(tb)
 
+        return tool_data
+
     def _on_tool_closed(self, tool):
         """
         Internal callback function that is called when a tool is closed
